@@ -6,9 +6,15 @@ import ocean_spark.extra_links
 
 def get_provider_info() -> Dict:
     return {
+        "versions": [
+            "0.1.3",
+            "0.1.2",
+            "0.1.1",
+            "0.1.0",
+        ],
         "package-name": "ocean-spark-airflow-provider",
         "name": "Ocean for Spark Airflow Provider",
-        "description": "TODO(crezvoy): add description",
+        "description": "Apache Airflow connector for Ocean for Apache Spark",
         "hook-class-names": ["ocean_spark.hooks.OceanSparkHook"],
         "connection-types": [
             {
